/**
 * 群组模型。此数据来源于家庭医生平台数据库的行政团队。
 *
 * 实际团队数据分为两部分：行政团队与临时讨论组，具体的与业务相关。医生在讨论组里，
 * 会出现两种：在行政团队内聊天，也可以在临时讨论组里聊天。
 */
"use strict";

var wlyyRepo = require("../repository/wlyy.repo");
var GROUP_TYPE = require('../include/commons').GROUP_TYPE;

/**
 * 判断是否为团队成员。
 *
 * @param groupId
 * @param groupType
 * @param doctorId
 * @param handler
 */
function isGroupMember(groupId, groupType, doctorId, handler){
    if(groupType === GROUP_TYPE.AdminTeam) {
        wlyyRepo.execQuery({
            "sql": "SELECT doctor_code user_id from wlyy_admin_team_member WHERE team_id=? and doctor_code=?",
            "args": [groupId, doctorId],
            "handler": handler
        });
    }else {
        wlyyRepo.execQuery({
            "sql": "SELECT member_code user_id from wlyy_talk_group_member WHERE group_code=? and member_code=?",
            "args": [groupId, doctorId],
            "handler": handler
        });
    }
}

/**
 * 获取团队成员。
 *
 * @param groupId
 * @param groupType
 * @param handler
 */
function getMembers(groupId, groupType, handler) {
    if(groupType === GROUP_TYPE.AdminTeam) {
        wlyyRepo.execQuery({
            "sql": "SELECT doctor_code user_id from wlyy_admin_team_member WHERE team_id=? AND available = 1",
            "args": [groupId],
            "handler": handler
        });
    } else {
        wlyyRepo.execQuery({
            "sql": "SELECT member_code user_id from wlyy_talk_group_member WHERE group_code=?",
            "args": [groupId],
            "handler": handler
        });
    }
}

exports.isGroupMember = isGroupMember;
exports.getMembers = getMembers;
